@@ -19,7 +19,7 @@ class Marketplace(ABC):
         pass
 
     @abstractmethod
-    def refresh_prices(self, ids: list[int], values: list[int]):
+    def refresh_prices(self, products_data: dict):
         pass
 
     @abstractmethod
